@@ -69,6 +69,18 @@ class BaseProcess(object):
     ]
     signals = []
 
+    @classmethod
+    def as_process(cls, defer=True, args=None, kwargs=None):
+        args, kwargs = args or [], kwargs or {}
+        p = cls(*args, **kwargs)
+        return p.start_process(defer=defer)
+
+    @classmethod
+    def as_thread(cls, daemon=False, defer=True, args=None, kwargs=None):
+        args, kwargs = args or [], kwargs or {}
+        p = cls(*args, **kwargs)
+        return p.start_threaded(daemon=daemon, defer=defer)
+
     def __init__(self, setupfunc=None, suppress_exceptions=False, framerate=None):
         """Initialize a new :class:`BaseProcess` instance.
 
